%define build_plf 0
%{?_with_plf: %global build_plf 1}

%define tiff22pnm_version 2014-01-09

# enablelzw = 0 (don't build with LZW compression support)
# enablelzw = 1 (build with LZW compression support)
# Currently we use enablelzw = 0 due to Unisys LZW patents.
%define enablelzw       0

%if %build_plf
%define enablelzw       1
%endif

Summary:	Convert raster images to PostScript or PDF
Name:		sam2p
Version:	0.49.4
Release:	%mkrel 2
License:	GPLv2+
Group:		Publishing
URL:		https://github.com/pts/sam2p
Source0:	https://github.com/pts/sam2p/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/pts/tif22pnm/archive/%{tiff22pnm_version}.tar.gz
# (tv) fix linking:
Patch0:		fix-linking.diff
Patch1:		sam2p-0.49.2-mga-deps.diff
# from gentoo
Patch17:	sam2p-build-fix.patch
Patch18:	tif22pnm-build-fix.patch
Requires:	ghostscript
Requires:	jpeg-progs
BuildRequires:	libjpeg-progs
Requires:	netpbm
BuildRequires:	libtiff-devel
BuildRequires:	pkgconfig(libpng16)

%description
sam2p is a UNIX command line utility written in ANSI C++ that converts
many raster (bitmap) image formats into Adobe PostScript or PDF files
and several other formats. The images are not vectorized. sam2p gives
full control to the user to specify standards-compliance, compression,
and bit depths. In some cases sam2p can compress an image 100 times
smaller than the PostScript output of many other common image
converters. sam2p provides ZIP, RLE and LZW (de)compression filters
even on Level1 devices.

%prep
%autosetup -p1 -n %{name}-%{version} -a 1

# configure.in files are deprecated
mv configure.{in,ac}

# missing include for memset
sed -i '1s;^;#include <string.h>\n;' pts_defl.c

%build
%global build_cflags %build_cflags -std=gnu17
%global build_cxxflags %build_cxxflags -std=gnu++17

pushd tif22pnm-%{tiff22pnm_version}
autoconf -f
%configure \
	--with-libtiff-idir=%{_includedir} \
	--with-libpng-idir=%{_includedir}/libpng16 \
	--with-libtiff-ldir=%{_libdir} \
	--with-libpng-ldir=%{_libdir} \
	--enable-debug=yes
make
cp tif22pnm png22pnm ../
cp -p README ../README.tif22pnm
popd

autoconf -f
%configure \
%if %build_plf
	--enable-lzw \
%endif
	--enable-gif

%make_build


%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 sam2p tif22pnm png22pnm %{buildroot}%{_bindir}

%files
%license COPYING
%doc README README.tif22pnm examples contrib
%{_bindir}/sam2p
%{_bindir}/tif22pnm
%{_bindir}/png22pnm


%changelog
* Thu May 22 2025 daviddavid <daviddavid> 0.49.4-2.mga10
+ Revision: 2185616
- fix build with gcc 15 using -std=gnu17
+ wally <wally>
- properly use our build flags

* Tue Oct 15 2024 daviddavid <daviddavid> 0.49.4-1.mga10
+ Revision: 2107093
- new version: 0.49.4

* Tue Oct 15 2024 daviddavid <daviddavid> 0.49.3-7.mga10
+ Revision: 2107088
- fix build with GCC 14

* Mon Dec 12 2022 ns80 <ns80> 0.49.3-6.mga9
+ Revision: 1921109
- rebuild for new libtiff

* Mon Mar 28 2022 umeabot <umeabot> 0.49.3-5.mga9
+ Revision: 1830423
- Mageia 9 Mass Rebuild

* Tue Dec 08 2020 ns80 <ns80> 0.49.3-4.mga8
+ Revision: 1654525
- add patches for CVE-2017-1462[89], CVE-2017-1463[0167], CVE-2017-16663, CVE-2018-7487, CVE-2018-755[134], CVE-2018-12578, CVE-2018-12601 (mga#27746)

* Fri Feb 14 2020 umeabot <umeabot> 0.49.3-3.mga8
+ Revision: 1516732
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.49.3-2.mga7
+ Revision: 1300920
- Mageia 7 Mass Rebuild

* Wed Sep 20 2017 cjw <cjw> 0.49.3-1.mga7
+ Revision: 1156086
- 0.49.3
- fix build with gcc7 and perl 5.26

* Fri Feb 12 2016 umeabot <umeabot> 0.49.2-9.mga6
+ Revision: 958836
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 danf <danf> 0.49.2-8.mga6
+ Revision: 893390
- Override linker to fix broken AC_PTS_GCC_LINKS_CXX on i686
- Enable debuginfo generation

* Wed Oct 15 2014 umeabot <umeabot> 0.49.2-6.mga5
+ Revision: 747763
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.49.2-5.mga5
+ Revision: 689023
- Mageia 5 Mass Rebuild

* Sat Sep 13 2014 danf <danf> 0.49.2-4.mga5
+ Revision: 674937
- added dep patch to fix glibc warning that breaks build

* Sun Feb 16 2014 tv <tv> 0.49.2-3.mga5
+ Revision: 592708
- update tif22pnm (should be a separate SRPM!!!)
- fix building with libpng16
- patch 0: fix linking
- try building with libpng16
- try building with libpng16

* Mon Oct 21 2013 fwang <fwang> 0.49.2-1.mga4
+ Revision: 537201
- drop old patches
- new version 0.49.2
- use configure2_5x
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0.49.1-3.mga3
+ Revision: 381666
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 08 2012 malo <malo> 0.49.1-2.mga3
+ Revision: 328950
- update RPM group

* Sat Feb 04 2012 fwang <fwang> 0.49.1-1.mga2
+ Revision: 204407
- new version 0.49.1

* Sun Dec 25 2011 fwang <fwang> 0.44.14-7.mga2
+ Revision: 187449
- correct includedir
- br png12
- rebuild for new libtiff

* Tue Apr 26 2011 rtp <rtp> 0.44.14-6.mga1
+ Revision: 91670
- Add patch from Debian to fix build with gcc-4.5

* Tue Jan 11 2011 pterjan <pterjan> 0.44.14-5.mga1
+ Revision: 5541
- imported package sam2p


* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0.44.14-5mdv2010.1
+ Revision: 523961
- rebuilt for 2010.1

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.44.14-4mdv2010.0
+ Revision: 426972
- rebuild

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 0.44.14-3mdv2009.1
+ Revision: 351538
- rebuild

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 0.44.14-2mdv2009.0
+ Revision: 225362
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 0.44.14-1mdv2008.1
+ Revision: 126941
- kill re-definition of %%buildroot on Pixel's request


* Sun Feb 18 2007 Giuseppe Ghibò <ghibo@mandriva.com> 0.44.14-1mdv2007.0
+ Revision: 122276
- Import sam2p

* Fri May 05 2006 Giuseppe Ghibò <ghibo@mandriva.com> 0.44.14-1mdk
- Release: 0.44-14.
- Updated tif22pnm (0.12).
- Rebuilt Patch0.
- %%mkrel.

* Sat Aug 06 2005 Giuseppe Ghibò <ghibo@mandriva.com> 0.44-1mdk
- Release: 0.44.
- Removed Patch0 (merged upstream).

* Thu Feb 24 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 0.42-4mdk
- Disable icecream
- Disable parallel building.

* Mon Feb 21 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.42-3mdk
- 64-bit fixes
- fix buildrequires

* Fri Feb 18 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 0.42-2mdk
- Fix requires (libjpeg-progs instead of jpeg-progs)

* Thu Feb 17 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 0.42-1mdk
- Initial release.

